@@ -6,18 +6,19 @@ class Line():
                  no: int = 1,
                  nodes_no: str = '1 2',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Line Tag
             nodes_no (str): Nodes Defining Line
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -32,28 +33,31 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def Polyline(self,
+    @staticmethod
+    def Polyline(
                  no: int = 1,
                  nodes_no: str = '1 2',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Line Tag
             nodes_no (str): Nodes Defining Polyline
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -71,32 +75,35 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def Arc(self,
-            no: int = 1,
-            nodes_no: str = [1,2],
-            control_point: list = [10,0,0], # X,Y,Z
+    @staticmethod
+    def Arc(
+            no: int,
+            nodes_no: list,
+            control_point: list,
             alpha_adjustment_target = LineArcAlphaAdjustmentTarget.ALPHA_ADJUSTMENT_TARGET_BEGINNING_OF_ARC,
             comment: str = '',
-            params: dict = {}):
+            params: dict = None,
+            model = Model):
 
         '''
         Args:
             no (int): Line Tag
-            nodes_no (list): Node Tags Defining Arc
+            nodes_no (list): Node Tags Defining Arc; [first_node, second_node]
             control_point (list): Control Point for Arc in [X, Y, Z]
             alpha_adjustment_target (enum): Line Arc Alpha Adjustment Target Enumeration
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -120,19 +127,21 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def Circle(self,
+    @staticmethod
+    def Circle(
                 no: int = 1,
                 center_of_cirle: list = [20,0,0],
                 circle_radius: float = 1.0,
                 point_of_normal_to_circle_plane: list = [1,0,0],
                 comment: str = '',
-                params: dict = {}):
+                params: dict = None, model = Model):
 
         '''
         Args:
@@ -142,11 +151,11 @@ class Line():
             circle_radius (float): Magnitude of Circle Radius
             point_of_normal_to_circle_plane (list): Vector from Circle Centre to this Point [X, Y, Z] defines Vector Normal to Circle Plane
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -173,13 +182,15 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def EllipticalArc(self,
+    @staticmethod
+    def EllipticalArc(
                       no: int = 1,
                       p1_control_point: list = [0,-6,0],
                       p2_control_point: list = [20,-6,0],
@@ -187,7 +198,7 @@ class Line():
                       arc_angle_alpha: float = 0,
                       arc_angle_beta: float = 3.141592653589793,
                       comment: str = '',
-                      params: dict = {}):
+                      params: dict = None, model = Model):
 
         '''
         Args:
@@ -198,11 +209,11 @@ class Line():
             arc_angle_alpha (float): Alpha Arc Angle (in Radians)
             arc_angle_beta (float): Beta Arc Angle (in Radians)
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -233,18 +244,20 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def Ellipse(self,
+    @staticmethod
+    def Ellipse(
                 no: int = 1,
                 nodes_no: list = [5,10],
                 ellipse_control_point: list = [18,-4.8,0],
                 comment: str = '',
-                params: dict = {}):
+                params: dict = None, model = Model):
 
         '''
         Args:
@@ -252,11 +265,11 @@ class Line():
             nodes_no (list): Node Tags on Line of Ellipse
             ellipse_control_point (list): Ellipse Control Point [X, Y, Z]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -281,19 +294,21 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def Parabola(self,
+    @staticmethod
+    def Parabola(
                  no: int = 1,
                  nodes_no: str = [3,8],
                  parabola_control_point: list = [10,-3,0],
                  parabola_alpha: float = 0,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None, model = Model):
 
         '''
         Args:
@@ -302,11 +317,11 @@ class Line():
             parabola_control_point (list): Parabola Control Point [X, Y, Z]
             parabola_alpha (float): Alpha Angle (in Radians)
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -333,28 +348,30 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def Spline(self,
+    @staticmethod
+    def Spline(
                no: int = 1,
                nodes_no: str = '1 3 5',
                comment: str = '',
-               params: dict = {}):
+               params: dict = None, model = Model):
 
         '''
         Args:
             no (int): Line Tag
             nodes_no (str): Node Tags on Line of Spline
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -372,32 +389,36 @@ class Line():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
 
-    def NURBS(self,
+    @staticmethod
+    def NURBS(
               no: int = 1,
               nodes_no: str = '1 2',
-              control_points: list = [[0,0,0],[2.33,0,-3,4],[10,0,-11],[17.66,0,-3.4],[20,0,0]],
-              weights = [1,1,1,1,1],
+              control_points: list = None,
+              weights: list = None,
+              order: int = 0,
               comment: str = '',
-              params: dict = {}):
+              params: dict = None, model = Model):
 
         '''
         Args:
             no (int): Line Tag
-            nodes_no (str): Node Tags on Line of NURBS Curve
-            control_points (list): Nested List of Respective Control Point's Cartesian Co-Ordinates
-            weights (list): Weights of Control Points
+            nodes_no (str): Nodes creating the curve. By default theese are taken as control points.
+            control_points (list of lists, optional): Nested List of Respective Control Point's Cartesian Co-Ordinates
+            weights (list, optional): Control points weights e.g. [1,1,1]
+            order (int, optional): Order of the curve with 3 as default value
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line
-        clientObject = Model.clientModel.factory.create('ns0:line')
+        clientObject = model.clientModel.factory.create('ns0:line')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -411,28 +432,31 @@ class Line():
         # Type
         clientObject.type = LineType.TYPE_NURBS.name
 
-        if len(control_points) != len(weights):
-            print("WARNING: The number of weigths prescribed must equal the number of control points defined.")
+        # Order
+        if control_points and weights and order:
+            if len(control_points) != len(weights):
+                print("WARNING: The number of weigths prescribed must equal the number of control points defined.")
+            clientObject.nurbs_order = order
+
+            # TODO: bug 24721
+            nurbs_control_points = []
+            for i,j in enumerate(control_points):
+                point = model.clientModel.factory.create('ns0:line_nurbs_control_points_by_components')
+                point.no = i+1
+                point.global_coordinate_x = control_points[i][0]
+                point.global_coordinate_y = control_points[i][1]
+                point.global_coordinate_z = control_points[i][2]
+                point.weight = 1 if not weights else weights[i]
+                nurbs_control_points.append(point)
+            clientObject.nurbs_control_points_by_components = model.clientModel.factory.create('ns0:line_nurbs_control_points_by_components')
 
-        '''
-        TODO: bug 24721
-        nurbs_control_points = []
-        for i,j in enumerate(control_points):
-            point = Model.clientModel.factory.create('ns0:line_nurbs_control_points_by_components')
-            point.no = i+1
-            point.global_coordinate_x = control_points[i][0]
-            point.global_coordinate_y = control_points[i][1]
-            point.global_coordinate_z = control_points[i][2]
-            point.weight = weights[i]
-            nurbs_control_points.append(point)
-        #clientObject.nurbs_control_points_by_components = Model.clientModel.factory.create('ns0:line_nurbs_control_points_by_components')
-        '''
         # Comment
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Line to client model
-        Model.clientModel.service.set_line(clientObject)
+        model.clientModel.service.set_line(clientObject)
