@@ -1,22 +1,24 @@
 from RFEM.initModel import clearAtributes, Model
 
+
 class Material():
     def __init__(self,
                  no: int = 1,
                  name: str = 'S235',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Material Tag
             name (str): Name of Desired Material (As Named in RFEM Database)
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Material
-        clientObject = Model.clientModel.factory.create('ns0:material')
+        clientObject = model.clientModel.factory.create('ns0:material')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -31,8 +33,9 @@ class Material():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add material to client model
-        Model.clientModel.service.set_material(clientObject)
+        model.clientModel.service.set_material(clientObject)
