@@ -5,18 +5,19 @@ class Opening():
                  no: int = 1,
                  lines_no: str = '1 2 3 4',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Opening Tag
             lines_no (str): Tags of Lines defining Opening
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Opening
-        clientObject = Model.clientModel.factory.create('ns0:opening')
+        clientObject = model.clientModel.factory.create('ns0:opening')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -31,8 +32,9 @@ class Opening():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Opening to client model
-        Model.clientModel.service.set_opening(clientObject)
+        model.clientModel.service.set_opening(clientObject)
