@@ -1,5 +1,88 @@
 from RFEM.enums import SurfaceGeometry, SurfaceLoadDistributionDirection, SurfaceType
-from RFEM.initModel import *
+from RFEM.initModel import Model, clearAtributes, ConvertToDlString
+import math
+
+def CreateGeometryAndSetToModel(no, surface_type, boundary_lines_no, geometry_type, geometry_type_parameters, thickness = None, comment = None, params = None, model = Model):
+    '''
+        Args:
+            no (int): Surface Tag
+            surface_type (enum): Surface Type Enumeration
+            boundary_lines_no (str): Tags of Lines defining Standard Surface
+            geometry_type (enum): Geometry Type Enumeration
+            geometry_type_parameters (list): Geometry Type Parameters
+                for geometry_type == SurfaceGeometry.GEOMETRY_NURBS:
+                    geometry_type_parameters = [nurbs_control_point_count_in_direction_u, nurbs_control_point_count_in_direction_v, nurbs_order_in_direction_u, nurbs_order_in_direction_v]
+                for geometry_type == SurfaceGeometry.GEOMETRY_PLANE:
+                    geometry_type_parameters = None
+                for geometry_type == SurfaceGeometry.GEOMETRY_QUADRANGLE:
+                    geometry_type_parameters = [quadrangle_corner_node_1, quadrangle_corner_node_2, quadrangle_corner_node_3, quadrangle_corner_node_4]
+                for geometry_type == SurfaceGeometry.GEOMETRY_ROTATED:
+                    geometry_type_parameters = [rotated_angle_of_rotation, [rotated_point_p_x, rotated_point_p_y, rotated_point_p_z], [rotated_point_r_x, rotated_point_r_y, rotated_point_r_z], rotated_boundary_line]
+            thickness (int): Tag of Thickness assigned to Standard Surface
+            comment (str, optional): Comments
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
+        '''
+    # Client model | Surface
+    clientObject = model.clientModel.factory.create('ns0:surface')
+
+    # Clears object atributes | Sets all atributes to None
+    clearAtributes(clientObject)
+
+    # Surface No.
+    clientObject.no = no
+
+    # Surface Type
+    clientObject.type = surface_type.name
+
+    # Geometry Type
+    boundary_lines_list = boundary_lines_no.split(sep= ' ')
+    if geometry_type.name == 'GEOMETRY_NURBS':
+        if len(geometry_type_parameters) != 4:
+            raise Exception('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
+        for line in boundary_lines_list:
+            if model.clientModel.service.get_line(int(line))['type'] != 'TYPE_NURBS':
+                raise Exception('WARNING: For a NURBS Surface, the boundary lines need to be NURBS Curves')
+        clientObject.nurbs_control_point_count_in_direction_u = geometry_type_parameters[0]
+        clientObject.nurbs_control_point_count_in_direction_v = geometry_type_parameters[1]
+        clientObject.nurbs_order_in_direction_u = geometry_type_parameters[2]
+        clientObject.nurbs_order_in_direction_v = geometry_type_parameters[3]
+    elif geometry_type.name == 'GEOMETRY_PLANE':
+        geometry_type_parameters = None
+    elif geometry_type.name == 'GEOMETRY_ROTATED':
+        clientObject.rotated_angle_of_rotation = geometry_type_parameters[0] * (math.pi/180)
+        clientObject.rotated_point_p_x = geometry_type_parameters[1][0]
+        clientObject.rotated_point_p_y = geometry_type_parameters[1][1]
+        clientObject.rotated_point_p_z = geometry_type_parameters[1][2]
+        clientObject.rotated_point_r_x = geometry_type_parameters[2][0]
+        clientObject.rotated_point_r_y = geometry_type_parameters[2][1]
+        clientObject.rotated_point_r_z = geometry_type_parameters[2][2]
+        clientObject.rotated_boundary_line = geometry_type_parameters[3]
+    elif geometry_type.name == 'GEOMETRY_QUADRANGLE':
+        if len(geometry_type_parameters) != 4:
+            raise Exception('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
+        clientObject.quadrangle_corner_node_1 = geometry_type_parameters[0]
+        clientObject.quadrangle_corner_node_2 = geometry_type_parameters[1]
+        clientObject.quadrangle_corner_node_3 = geometry_type_parameters[2]
+        clientObject.quadrangle_corner_node_4 = geometry_type_parameters[3]
+    clientObject.geometry = geometry_type.name
+
+    # Lines No. (e.g. "5 7 8 12")
+    clientObject.boundary_lines = ConvertToDlString(boundary_lines_no)
+
+    # Thickness
+    if type == 'TYPE_STANDARD'or type == 'TYPE_MEMBRANE' or type == 'TYPE_WITHOUT_MEMBRANE_TENSION':
+        clientObject.thickness = thickness
+
+    # Comment
+    clientObject.comment = comment
+
+    # Adding optional parameters via dictionary
+    if params:
+        for key in params:
+            clientObject[key] = params[key]
+
+    # Add Surface to client model
+    model.clientModel.service.set_surface(clientObject)
 
 class Surface():
     def __init__(self,
@@ -7,7 +90,8 @@ class Surface():
                  boundary_lines_no: str = '1 2 3 4',
                  thickness: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -15,11 +99,11 @@ class Surface():
             boundary_lines_no (str): Tags of Lines defining Surface
             thickness (int): Tag of Thickness assigned to Surface
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        clientObject = model.clientModel.factory.create('ns0:surface')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -37,20 +121,23 @@ class Surface():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Surface to client model
-        Model.clientModel.service.set_surface(clientObject)
+        model.clientModel.service.set_surface(clientObject)
 
-    def Standard(self,
+    @staticmethod
+    def Standard(
                  no: int = 1,
                  geometry_type = SurfaceGeometry.GEOMETRY_PLANE,
                  geometry_type_parameters = None,
                  boundary_lines_no: str = '1 2 3 4',
                  thickness: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -66,39 +153,20 @@ class Surface():
             boundary_lines_no (str): Tags of Lines defining Standard Surface
             thickness (int): Tag of Thickness assigned to Standard Surface
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
-        # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        CreateGeometryAndSetToModel(no, SurfaceType.TYPE_STANDARD, boundary_lines_no, geometry_type, geometry_type_parameters, thickness, comment, params, model)
 
-        # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
-
-        # Surface No.
-        clientObject.no = no
-
-        # Surface Type
-        clientObject.type = SurfaceType.TYPE_STANDARD.name
-
-        # Reptitive code between various functions migrated to a private method
-        self.type = SurfaceType.TYPE_STANDARD.name
-        self.boundary_lines_no = boundary_lines_no
-        self.geometry_type = geometry_type
-        self.geometry_type_parameters = geometry_type_parameters
-        self.thickness = thickness
-        self.comment = comment
-        self.params = params
-        self.clientObject = clientObject
-        self.__CreateGeometryAndSetToModel(self)
-
-    def WithoutThickness(self,
+    @staticmethod
+    def WithoutThickness(
                  no: int = 1,
                  geometry_type = SurfaceGeometry.GEOMETRY_PLANE,
                  geometry_type_parameters = None,
                  boundary_lines_no: str = '1 2 3 4',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -113,38 +181,20 @@ class Surface():
                     geometry_type_parameters = [quadrangle_corner_node_1, quadrangle_corner_node_2, quadrangle_corner_node_3, quadrangle_corner_node_4]
             boundary_lines_no (str): Tags of Lines defining Without Thickness Surface
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
-        # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        CreateGeometryAndSetToModel(no, SurfaceType.TYPE_WITHOUT_THICKNESS, boundary_lines_no, geometry_type, geometry_type_parameters, comment=comment, params=params, model=model)
 
-        # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
-
-        # Surface No.
-        clientObject.no = no
-
-        # Surface Type
-        clientObject.type = SurfaceType.TYPE_WITHOUT_THICKNESS.name
-
-        # Reptitive code between various functions migrated to a private method
-        self.type = SurfaceType.TYPE_WITHOUT_THICKNESS.name
-        self.boundary_lines_no = boundary_lines_no
-        self.geometry_type = geometry_type
-        self.geometry_type_parameters = geometry_type_parameters
-        self.comment = comment
-        self.params = params
-        self.clientObject = clientObject
-        self.__CreateGeometryAndSetToModel(self)
-
-    def Rigid(self,
+    @staticmethod
+    def Rigid(
                  no: int = 1,
                  geometry_type = SurfaceGeometry.GEOMETRY_PLANE,
                  geometry_type_parameters = None,
                  boundary_lines_no: str = '1 2 3 4',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -159,39 +209,21 @@ class Surface():
                     geometry_type_parameters = [quadrangle_corner_node_1, quadrangle_corner_node_2, quadrangle_corner_node_3, quadrangle_corner_node_4]
             boundary_lines_no (str): Tags of Lines defining Rigid Surface
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
-        # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        CreateGeometryAndSetToModel(no, SurfaceType.TYPE_RIGID, boundary_lines_no, geometry_type, geometry_type_parameters, comment=comment, params=params, model=model)
 
-        # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
-
-        # Surface No.
-        clientObject.no = no
-
-        # Surface Type
-        clientObject.type = SurfaceType.TYPE_RIGID.name
-
-        # Reptitive code between various functions migrated to a private method
-        self.type = SurfaceType.TYPE_RIGID.name
-        self.boundary_lines_no = boundary_lines_no
-        self.geometry_type = geometry_type
-        self.geometry_type_parameters = geometry_type_parameters
-        self.comment = comment
-        self.params = params
-        self.clientObject = clientObject
-        self.__CreateGeometryAndSetToModel(self)
-
-    def Membrane(self,
+    @staticmethod
+    def Membrane(
                  no: int = 1,
                  geometry_type = SurfaceGeometry.GEOMETRY_PLANE,
                  geometry_type_parameters = None,
                  boundary_lines_no: str = '1 2 3 4',
                  thickness: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -207,40 +239,21 @@ class Surface():
             boundary_lines_no (str): Tags of Lines defining Membrane Surface
             thickness (int): Tag of Thickness assigned to Membrane Surface
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
-        # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        CreateGeometryAndSetToModel(no, SurfaceType.TYPE_WITHOUT_THICKNESS, boundary_lines_no, geometry_type, geometry_type_parameters, thickness, comment, params, model)
 
-        # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
-
-        # Surface No.
-        clientObject.no = no
-
-        # Surface Type
-        clientObject.type = SurfaceType.TYPE_MEMBRANE.name
-
-        # Reptitive code between various functions migrated to a private method
-        self.type = SurfaceType.TYPE_MEMBRANE.name
-        self.boundary_lines_no = boundary_lines_no
-        self.geometry_type = geometry_type
-        self.geometry_type_parameters = geometry_type_parameters
-        self.thickness = thickness
-        self.comment = comment
-        self.params = params
-        self.clientObject = clientObject
-        self.__CreateGeometryAndSetToModel(self)
-
-    def WithoutMemberaneTension(self,
+    @staticmethod
+    def WithoutMemberaneTension(
                  no: int = 1,
                  geometry_type = SurfaceGeometry.GEOMETRY_PLANE,
                  geometry_type_parameters = None,
                  boundary_lines_no: str = '1 2 3 4',
                  thickness: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -256,33 +269,13 @@ class Surface():
             boundary_lines_no (str): Tags of Lines defining Without Membrane Tension Surface
             thickness (int): Tag of Thickness assigned to Without Membrane Tension Surface
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
-        # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        CreateGeometryAndSetToModel(no, SurfaceType.TYPE_WITHOUT_THICKNESS, boundary_lines_no, geometry_type, geometry_type_parameters, thickness, comment, params, model)
 
-        # Clears object atributes | Sets all atributes to None
-        clearAtributes(clientObject)
-
-        # Surface No.
-        clientObject.no = no
-
-        # Surface Type
-        clientObject.type = SurfaceType.TYPE_WITHOUT_MEMBRANE_TENSION.name
-
-        # Reptitive code between various functions migrated to a private method
-        self.type = SurfaceType.TYPE_WITHOUT_MEMBRANE_TENSION.name
-        self.boundary_lines_no = boundary_lines_no
-        self.geometry_type = geometry_type
-        self.geometry_type_parameters = geometry_type_parameters
-        self.thickness = thickness
-        self.comment = comment
-        self.params = params
-        self.clientObject = clientObject
-        self.__CreateGeometryAndSetToModel(self)
-
-    def LoadDistribution(self,
+    @staticmethod
+    def LoadDistribution(
                  no: int = 1,
                  boundary_lines_no: str = '1 2 3 4',
                  load_transfer_direction = SurfaceLoadDistributionDirection.LOAD_TRANSFER_DIRECTION_IN_X,
@@ -295,7 +288,8 @@ class Surface():
                  loaded_members = None,
                  loaded_lines = None,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -311,11 +305,11 @@ class Surface():
             loaded_members (str): Tag of Loaded Members
             loaded_lines (str): Tag of Loaded Lines
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Surface
-        clientObject = Model.clientModel.factory.create('ns0:surface')
+        clientObject = model.clientModel.factory.create('ns0:surface')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -359,54 +353,9 @@ class Surface():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Surface to client model
-        Model.clientModel.service.set_surface(clientObject)
-
-    def __CreateGeometryAndSetToModel(self):
-
-        # Geometry Type
-        boundary_lines_list = self.boundary_lines_no.split(sep= ' ')
-
-        if self.geometry_type.name == 'GEOMETRY_NURBS':
-            if len(self.geometry_type_parameters) != 4:
-                raise Exception('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
-            for line in boundary_lines_list:
-                if Model.clientModel.service.get_line(int(line))['type'] != 'TYPE_NURBS':
-                    raise Exception('WARNING: For a NURBS Surface, the boundary lines need to be NURBS Curves')
-            self.clientObject.nurbs_control_point_count_in_direction_u = self.geometry_type_parameters[0]
-            self.clientObject.nurbs_control_point_count_in_direction_v = self.geometry_type_parameters[1]
-            self.clientObject.nurbs_order_in_direction_u = self.geometry_type_parameters[2]
-            self.clientObject.nurbs_order_in_direction_v = self.geometry_type_parameters[3]
-
-        elif self.geometry_type.name == 'GEOMETRY_PLANE':
-            self.geometry_type_parameters = None
-
-        elif self.geometry_type.name == 'GEOMETRY_QUADRANGLE':
-            if len(self.geometry_type_parameters) != 4:
-                raise Exception('WARNING: The geometry type parameter needs to be of length 4. Kindly check list inputs for completeness and correctness.')
-            self.clientObject.quadrangle_corner_node_1 = self.geometry_type_parameters[0]
-            self.clientObject.quadrangle_corner_node_2 = self.geometry_type_parameters[1]
-            self.clientObject.quadrangle_corner_node_3 = self.geometry_type_parameters[2]
-            self.clientObject.quadrangle_corner_node_4 = self.geometry_type_parameters[3]
-
-        self.clientObject.geometry = self.geometry_type.name
-
-        # Lines No. (e.g. "5 7 8 12")
-        self.clientObject.boundary_lines = ConvertToDlString(self.boundary_lines_no)
-
-        # Thickness
-        if self.type == 'TYPE_STANDARD'or self.type == 'TYPE_MEMBRANE' or self.type == 'TYPE_WITHOUT_MEMBRANE_TENSION':
-            self.clientObject.thickness = self.thickness
-
-        # Comment
-        self.clientObject.comment = self.comment
-
-        # Adding optional parameters via dictionary
-        for key in self.params:
-            self.clientObject[key] = self.params[key]
-
-        # Add Surface to client model
-        Model.clientModel.service.set_surface(self.clientObject)
+        model.clientModel.service.set_surface(clientObject)
