@@ -7,7 +7,8 @@ class SurfaceSet():
                  surfaces_no: str = '2 4 7',
                  surface_set_type = SetType.SET_TYPE_GROUP,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -15,11 +16,11 @@ class SurfaceSet():
             surfaces_no (str): Tags of Surfaces Contained Within Surface Set
             surfaces_set_type (enum): Surface Set Type Enumeration
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Surface Set
-        clientObject = Model.clientModel.factory.create('ns0:surface_set')
+        clientObject = model.clientModel.factory.create('ns0:surface_set')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -37,17 +38,20 @@ class SurfaceSet():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Surface Set to client model
-        Model.clientModel.service.set_surface_set(clientObject)
+        model.clientModel.service.set_surface_set(clientObject)
 
-    def ContinuousSurfaces(self,
+    @staticmethod
+    def ContinuousSurfaces(
                  no: int = 1,
                  surfaces_no: str = '2 4 7',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -55,11 +59,11 @@ class SurfaceSet():
             surfaces_no (str): Tags of Surfaces Contained Within Continuous Surface Set
             surfaces_set_type (enum): Surface Set Type Enumeration
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Surface Set
-        clientObject = Model.clientModel.factory.create('ns0:surface_set')
+        clientObject = model.clientModel.factory.create('ns0:surface_set')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -77,28 +81,31 @@ class SurfaceSet():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Surface Set to client model
-        Model.clientModel.service.set_surface_set(clientObject)
+        model.clientModel.service.set_surface_set(clientObject)
 
-    def GroupOfSurfaces(self,
+    @staticmethod
+    def GroupOfSurfaces(
                  no: int = 1,
                  surfaces_no: str = '2 4 7',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Surfaces Set Tag
             surfaces_no (str): Tags of Surfaces Contained Within Group of Surfaces Surface Set
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Surface Set
-        clientObject = Model.clientModel.factory.create('ns0:surface_set')
+        clientObject = model.clientModel.factory.create('ns0:surface_set')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -116,8 +123,9 @@ class SurfaceSet():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Surface Set to client model
-        Model.clientModel.service.set_surface_set(clientObject)
+        model.clientModel.service.set_surface_set(clientObject)
