@@ -12,7 +12,8 @@ class Thickness():
                  material_no: int = 1,
                  uniform_thickness_d: float = 0.20,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -21,11 +22,11 @@ class Thickness():
             material_no (int): Tag of Material assigned to Thickness
             uniform_thickness_d (float): Magnitude of Thickness
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -51,19 +52,22 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def Uniform(self,
+    @staticmethod
+    def Uniform(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
                  properties = [0.2],
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -72,11 +76,11 @@ class Thickness():
             material_no (int): Tag of Material assigned to Thickness
             properties (list): Magnitude of Thickness [Thickness]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -104,19 +108,22 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def Variable_3Nodes(self,
+    @staticmethod
+    def Variable_3Nodes(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
                  properties = None,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -126,11 +133,11 @@ class Thickness():
             properties (list): Properties for 3 Nodes Variable Thickness Definition
                 properties = [thickness_d1, node_no_1, thickness_d2, node_no_2, thickness_d3, node_no_3]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -165,19 +172,22 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def Variable_2NodesAndDirection(self,
+    @staticmethod
+    def Variable_2NodesAndDirection(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
                  properties = [0.18, 1, 0.18, 2, ThicknessDirection.THICKNESS_DIRECTION_IN_X],
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -187,12 +197,12 @@ class Thickness():
             properties (list): Properties for 2 Nodes and Direction Variable Thickness Definition
                 properties = [thickness_d1, node_no_1, thickness_d2, node_no_2, direction]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
 
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -224,19 +234,22 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def Variable_4SurfaceCorners(self,
+    @staticmethod
+    def Variable_4SurfaceCorners(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
                  properties = None,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -246,12 +259,12 @@ class Thickness():
             properties (list): Properties for 4 Surface Corners Variable Definition
                 properties = [thickness_d1, node_no_1, thickness_d2, node_no_2, thickness_d3, node_no_3, thickness_d4, node_no_4]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
 
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -288,19 +301,22 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def Variable_Circle(self,
+    @staticmethod
+    def Variable_Circle(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
                  properties = None,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -310,11 +326,11 @@ class Thickness():
             properties (list): Properties for Circular Thickness Definition
                 properties = [thickness_circle_center_dC, thickness_circle_line_dR]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -345,18 +361,21 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def Layers(self,
+    @staticmethod
+    def Layers(
                  no: int = 1,
                  name: str = None,
-                 layers = [[0, 1, 200, 0.0, '']],
+                 layers = [[0, 1, 0.2, 0.0, '']],
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         NOTE: Available only for Special Solution Add-on Multilayer Surfaces.
@@ -368,15 +387,15 @@ class Thickness():
             properties (list): Nested List of Layer Properties
                 properties: [[thickness_type, material, thickness, rotation, comment], ...]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Check if Multilayer Surfaces Add-on is ON.
-        if not GetAddonStatus(Model.clientModel, AddOn.multilayer_surfaces_design_active):
-            SetAddonStatus(Model.clientModel, AddOn.multilayer_surfaces_design_active, True)
+        if not GetAddonStatus(model.clientModel, AddOn.multilayer_surfaces_design_active):
+            SetAddonStatus(model.clientModel, AddOn.multilayer_surfaces_design_active, True)
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -393,10 +412,10 @@ class Thickness():
         clientObject.type = ThicknessType.TYPE_LAYERS.name
 
         # Layers
-        clientObject.layers_reference_table = Model.clientModel.factory.create('ns0:thickness.layers_reference_table')
+        clientObject.layers_reference_table = model.clientModel.factory.create('ns0:thickness.layers_reference_table')
 
         for i,j in enumerate(layers):
-            tlrt = Model.clientModel.factory.create('ns0:thickness_layers_reference_table')
+            tlrt = model.clientModel.factory.create('ns0:thickness_layers_reference_table')
             tlrt.no = no
             tlrt.layer_no = i+1
             tlrt.layer_type = None
@@ -415,13 +434,15 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def ShapeOrthotropy(self,
+    @staticmethod
+    def ShapeOrthotropy(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
@@ -430,7 +451,8 @@ class Thickness():
                  consideration_of_self_weight = [ThicknessShapeOrthotropySelfWeightDefinitionType.SELF_WEIGHT_COMPUTED_FROM_PARAMETERS, 0.18],
                  parameters = [0.18, 0.18],
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -462,11 +484,11 @@ class Thickness():
                 for orthotropy_type == ThicknessOrthotropyType.GRILLAGE:
                     parameters = [slab_thickness, rib_spacing_x, rib_spacing_y, rib_width_x, rib_width_y]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -556,13 +578,15 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
 
-    def StiffnessMatrix(self,
+    @staticmethod
+    def StiffnessMatrix(
                  no: int = 1,
                  name: str = None,
                  material_no: int = 1,
@@ -571,7 +595,8 @@ class Thickness():
                  coefficient_of_thermal_expansion: float = 0,
                  stiffness_matrix = [[0, 0, 0, 0, 0, 0],[0, 0, 0],[0, 0, 0, 0, 0, 0],[0, 0, 0, 0, 0, 0]],
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -597,11 +622,11 @@ class Thickness():
                                             [D66, D67, D68, D77, D78, D88],
                                             [D16, D17, D18, D27, D28, D38]]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Thickness
-        clientObject = Model.clientModel.factory.create('ns0:thickness')
+        clientObject = model.clientModel.factory.create('ns0:thickness')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -662,8 +687,9 @@ class Thickness():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Thickness to client model
-        Model.clientModel.service.set_thickness(clientObject)
+        model.clientModel.service.set_thickness(clientObject)
