@@ -5,17 +5,18 @@ class ImperfectionCase():
                  no: int = 1,
                  assigned_to_load_cases: str = '1',
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Imperfection Case Tag
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Imperfection Case
-        clientObject = Model.clientModel.factory.create('ns0:imperfection_case')
+        clientObject = model.clientModel.factory.create('ns0:imperfection_case')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -30,8 +31,9 @@ class ImperfectionCase():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Imperfection Case to client model
-        Model.clientModel.service.set_imperfection_case(clientObject)
+        model.clientModel.service.set_imperfection_case(clientObject)
