@@ -4,17 +4,18 @@ class ResultCombination():
     def __init__(self,
                  no: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
             no (int): Result Combination Tag
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Result Combination
-        clientObject = Model.clientModel.factory.create('ns0:result_combination')
+        clientObject = model.clientModel.factory.create('ns0:result_combination')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -26,8 +27,9 @@ class ResultCombination():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Result Combination to client model
-        Model.clientModel.service.set_result_combination(clientObject)
+        model.clientModel.service.set_result_combination(clientObject)
