@@ -10,7 +10,8 @@ class LineLoad():
                  load_direction = LoadDirectionType.LOAD_DIRECTION_LOCAL_Z,
                  magnitude: float = 0,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -20,11 +21,11 @@ class LineLoad():
             load_direction (enum): Load Direction Enumeration
             magnitude (float): Magnitude of Line Load
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line Load
-        clientObject = Model.clientModel.factory.create('ns0:line_load')
+        clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -56,22 +57,25 @@ class LineLoad():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Load Line Load to client model
-        Model.clientModel.service.set_line_load(load_case_no, clientObject)
+        model.clientModel.service.set_line_load(load_case_no, clientObject)
 
-    def Force(self,
+    @staticmethod
+    def Force(
                 no: int = 1,
                 load_case_no: int = 1,
                 lines_no: str = '1',
-                load_distribution= LineLoadDistribution.LOAD_DISTRIBUTION_UNIFORM,
-                load_direction= LineLoadDirection.LOAD_DIRECTION_LOCAL_Z,
-                load_parameter = None,
+                load_distribution = LineLoadDistribution.LOAD_DISTRIBUTION_UNIFORM,
+                load_direction = LineLoadDirection.LOAD_DIRECTION_LOCAL_Z,
+                load_parameter: list = None,
                 list_reference: bool= False,
                 comment: str = '',
-                params: dict = {}):
+                params: dict = None,
+                model = Model):
 
         '''
         Args:
@@ -105,11 +109,11 @@ class LineLoad():
                     load_parameter = [[distance, delta_distance, magnitude], ...]
             list_reference (bool): List Reference Bool
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line Load
-        clientObject = Model.clientModel.factory.create('ns0:line_load')
+        clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -218,12 +222,12 @@ class LineLoad():
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
-            clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
+            clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
 
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
                     raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
-                mlvlp = Model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
+                mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
                 mlvlp.no = i+1
                 mlvlp.distance = load_parameter[i][0]
                 mlvlp.delta_distance = load_parameter[i][1]
@@ -285,11 +289,11 @@ class LineLoad():
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
-            clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
+            clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
                     raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
-                mlvlp = Model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
+                mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
                 mlvlp.no = i+1
                 mlvlp.distance = load_parameter[i][0]
                 mlvlp.delta_distance = load_parameter[i][1]
@@ -308,22 +312,25 @@ class LineLoad():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Load Line Load to client model
-        Model.clientModel.service.set_line_load(load_case_no, clientObject)
+        model.clientModel.service.set_line_load(load_case_no, clientObject)
 
-    def Moment(self,
+    @staticmethod
+    def Moment(
                  no: int = 1,
                  load_case_no: int = 1,
                  lines_no: str = '1',
                  load_distribution = LineLoadDistribution.LOAD_DISTRIBUTION_UNIFORM,
                  load_direction = LineLoadDirection.LOAD_DIRECTION_LOCAL_Z,
-                 load_parameter = None,
+                 load_parameter: list = None,
                  list_reference: bool = False,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         '''
         Args:
@@ -355,11 +362,11 @@ class LineLoad():
                     load_parameter = [[distance, delta_distance, magnitude], ...]
             list_reference (bool): List Reference Bool
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line Load
-        clientObject = Model.clientModel.factory.create('ns0:line_load')
+        clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -468,12 +475,12 @@ class LineLoad():
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
-            clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
+            clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
 
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
                     raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
-                mlvlp = Model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
+                mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
                 mlvlp.no = i+1
                 mlvlp.distance = load_parameter[i][0]
                 mlvlp.delta_distance = load_parameter[i][1]
@@ -535,11 +542,11 @@ class LineLoad():
             except:
                 print("WARNING: LineLoad no: %x, load case: %x - Wrong data input." % (no, load_case_no))
 
-            clientObject.varying_load_parameters = Model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
+            clientObject.varying_load_parameters = model.clientModel.factory.create('ns0:line_load.varying_load_parameters')
             for i,j in enumerate(load_parameter):
                 if len(load_parameter[i]) != 3:
                     raise Exception('WARNING: The load parameter sub-lists need to be of length 3. Kindly check sub-list inputs for completeness and correctness.')
-                mlvlp = Model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
+                mlvlp = model.clientModel.factory.create('ns0:line_load_varying_load_parameters')
                 mlvlp.no = i+1
                 mlvlp.distance = load_parameter[i][0]
                 mlvlp.delta_distance = load_parameter[i][1]
@@ -558,20 +565,23 @@ class LineLoad():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Load Line Load to client model
-        Model.clientModel.service.set_line_load(load_case_no, clientObject)
+        model.clientModel.service.set_line_load(load_case_no, clientObject)
 
-    def Mass(self,
+    @staticmethod
+    def Mass(
                 no: int = 1,
                 load_case_no: int = 1,
                 lines_no: str = '1',
                 individual_mass_components: bool=True,
-                mass_components = None,
+                mass_components: list = None,
                 comment: str = '',
-                params: dict = {}):
+                params: dict = None,
+                model = Model):
         '''
         Args:
             no (int): Load Tag
@@ -584,11 +594,11 @@ class LineLoad():
                 for individual_mass_components == True:
                     mass_components = [mass_x, mass_y, mass_z]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         '''
 
         # Client model | Line Load
-        clientObject = Model.clientModel.factory.create('ns0:line_load')
+        clientObject = model.clientModel.factory.create('ns0:line_load')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -631,8 +641,9 @@ class LineLoad():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Load Line Load to client model
-        Model.clientModel.service.set_line_load(load_case_no, clientObject)
+        model.clientModel.service.set_line_load(load_case_no, clientObject)
