@@ -10,7 +10,8 @@ class NodalLoad():
                  load_direction= LoadDirectionType.LOAD_DIRECTION_GLOBAL_Z_OR_USER_DEFINED_W,
                  magnitude: float = 0.0,
                  comment: str= '',
-                 params: dict= {}):
+                 params: dict= None,
+                 model = Model):
         """
         Args:
             no (int): Load Tag
@@ -19,10 +20,10 @@ class NodalLoad():
             load_direction (enum): Load Direction Enumeration
             magnitude (float): Force Magnitude
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         """
         # Client model | Nodal Force
-        clientObject = Model.clientModel.factory.create('ns0:nodal_load')
+        clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -50,13 +51,15 @@ class NodalLoad():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Nodal Force to client model
-        Model.clientModel.service.set_nodal_load(load_case_no, clientObject)
+        model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
-    def Force(self,
+    @staticmethod
+    def Force(
               no: int= 1,
               load_case_no: int = 1,
               nodes_no: str= '1',
@@ -66,7 +69,8 @@ class NodalLoad():
               specific_direction: bool = False,
               shifted_display: bool = False,
               comment: str= '',
-              params= {}):
+              params: dict = None,
+              model = Model):
         """
         Args:
             no (int): Load Tag
@@ -96,7 +100,7 @@ class NodalLoad():
                     params={'shifted_display' : [offset_x, offset_y, offset_y, distance]}
         """
         # Client model | Nodal Force
-        clientObject = Model.clientModel.factory.create('ns0:nodal_load')
+        clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -197,9 +201,10 @@ class NodalLoad():
                 clientObject[key] = params[key]
 
         # Add Nodal Force to client model
-        Model.clientModel.service.set_nodal_load(load_case_no, clientObject)
+        model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
-    def Moment(self,
+    @staticmethod
+    def Moment(
               no: int= 1,
               load_case_no: int= 1,
               nodes_no: str= '1',
@@ -208,7 +213,8 @@ class NodalLoad():
               specific_direction: bool= False,
               shifted_display: bool= False,
               comment: str = '',
-              params: dict = {}):
+              params: dict = None,
+              model = Model):
         """
         Args:
             no (int): Load Tag
@@ -234,7 +240,7 @@ class NodalLoad():
                     params={'shifted_display' : [offset_x, offset_y, offset_y, distance]}
         """
         # Client model | Nodal Force
-        clientObject = Model.clientModel.factory.create('ns0:nodal_load')
+        clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -317,18 +323,20 @@ class NodalLoad():
                 clientObject[key] = params[key]
 
         # Add Nodal Force to client model
-        Model.clientModel.service.set_nodal_load(load_case_no, clientObject)
+        model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
-    def Components(self,
+    @staticmethod
+    def Components(
               no: int= 1,
               load_case_no: int= 1,
               nodes_no: str= '1',
-              components = [],
+              components: list = None,
               specific_direction: bool= False,
               force_eccentricity: bool= False,
               shifted_display: bool= False,
               comment: str= '',
-              params: dict= {}):
+              params: dict= None,
+              model = Model):
         """
         Args:
             no (int): Load Tag
@@ -353,7 +361,7 @@ class NodalLoad():
                     params={'shifted_display' : [offset_x, offset_y, offset_y, distance]}
         """
         # Client model | Nodal Force
-        clientObject = Model.clientModel.factory.create('ns0:nodal_load')
+        clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -453,16 +461,18 @@ class NodalLoad():
                 clientObject[key] = params[key]
 
         # Add Nodal Force to client model
-        Model.clientModel.service.set_nodal_load(load_case_no, clientObject)
+        model.clientModel.service.set_nodal_load(load_case_no, clientObject)
 
-    def Mass(self,
+    @staticmethod
+    def Mass(
               no: int = 1,
               load_case_no: int = 1,
               nodes_no: str = '1',
               individual_mass_components : bool = False,
-              mass = [],
+              mass: list = None,
               comment: str = '',
-              params: dict = {}):
+              params: dict = None,
+              model = Model):
         """
         Args:
             no (int): Load Tag
@@ -475,10 +485,10 @@ class NodalLoad():
                 elif individual_mass_components == True:
                     mass = [Mx, My, Mz, Ix, Iy, Iz]
             comment (str, optional): Comments
-            params (dict, optional): Parameters
+            params (dict, optional): Any WS Parameter relevant to the object and its value in form of a dictionary
         """
         # Client model | Nodal Force
-        clientObject = Model.clientModel.factory.create('ns0:nodal_load')
+        clientObject = model.clientModel.factory.create('ns0:nodal_load')
 
         # Clears object attributes | Sets all attributes to None
         clearAtributes(clientObject)
@@ -517,9 +527,9 @@ class NodalLoad():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        if 'individual_mass_components' not in params.keys():
+        if params:
             for key in params:
                 clientObject[key] = params[key]
 
         # Add Nodal Force to client model
-        Model.clientModel.service.set_nodal_load(load_case_no, clientObject)
+        model.clientModel.service.set_nodal_load(load_case_no, clientObject)
