@@ -4,10 +4,11 @@ class EnlargedColumnHead():
     def __init__(self,
                  no: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         # Client model | Enlarged Column Head
-        clientObject = Model.clientModel.factory.create('ns0:enlarged_column_head')
+        clientObject = model.clientModel.factory.create('ns0:enlarged_column_head')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -19,8 +20,9 @@ class EnlargedColumnHead():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Enlarged Column Head to client model
-        Model.clientModel.service.set_enlarged_column_head(clientObject)
+        model.clientModel.service.set_enlarged_column_head(clientObject)
