@@ -6,10 +6,11 @@ class Instersection():
                  surface_1: int = 1,
                  surface_2: int = 2,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         # Client model | Intersection
-        clientObject = Model.clientModel.factory.create('ns0:intersection')
+        clientObject = model.clientModel.factory.create('ns0:intersection')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -25,8 +26,9 @@ class Instersection():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Intersection to client model
-        Model.clientModel.service.set_intersection(clientObject)
+        model.clientModel.service.set_intersection(clientObject)
