@@ -4,10 +4,11 @@ class ResultSection():
     def __init__(self,
                  no: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         # Client model | Result Section
-        clientObject = Model.clientModel.factory.create('ns0:result_section')
+        clientObject = model.clientModel.factory.create('ns0:result_section')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -19,8 +20,9 @@ class ResultSection():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Result Section to client model
-        Model.clientModel.service.set_result_section(clientObject)
+        model.clientModel.service.set_result_section(clientObject)
