@@ -4,10 +4,11 @@ class MemberResultIntermediatePoint():
     def __init__(self,
                  no: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         # Client model | Member Result Intermediate Point
-        clientObject = Model.clientModel.factory.create('ns0:member_result_intermediate_point')
+        clientObject = model.clientModel.factory.create('ns0:member_result_intermediate_point')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -19,8 +20,9 @@ class MemberResultIntermediatePoint():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Member Result Intermediate Point to client model
-        Model.clientModel.service.set_member_result_intermediate_point(clientObject)
+        model.clientModel.service.set_member_result_intermediate_point(clientObject)
