@@ -4,10 +4,11 @@ class MemberStiffnessModification():
     def __init__(self,
                  no: int = 1,
                  comment: str = '',
-                 params: dict = {}):
+                 params: dict = None,
+                 model = Model):
 
         # Client model | Member Stiffness Modification
-        clientObject = Model.clientModel.factory.create('ns0:smember_stiffness_modification')
+        clientObject = model.clientModel.factory.create('ns0:smember_stiffness_modification')
 
         # Clears object atributes | Sets all atributes to None
         clearAtributes(clientObject)
@@ -19,8 +20,9 @@ class MemberStiffnessModification():
         clientObject.comment = comment
 
         # Adding optional parameters via dictionary
-        for key in params:
-            clientObject[key] = params[key]
+        if params:
+            for key in params:
+                clientObject[key] = params[key]
 
         # Add Member Stiffness Modification to client model
-        Model.clientModel.service.set_member_stiffness_modification(clientObject)
+        model.clientModel.service.set_member_stiffness_modification(clientObject)
