@@ -1,103 +1,9 @@
 import sys
-import csv
+import RFEM.dependencies
+import requests
+from suds.client import Client
 from RFEM.enums import ObjectTypes, ModelType, AddOn
-
-# Import SUDS module
-try:
-    sys.version_info[0] == 3
-except:
-    print('Must be using Python 3!')
-    input('Press Enter to exit...')
-    sys.exit()
-
-try:
-    from suds.client import Client
-except:
-    print('SUDS library is not installed in your Python env.')
-    instSUDS = input('Do you want to install it (y/n)? ')
-    instSUDS = instSUDS.lower()
-    if instSUDS == 'y':
-        # Subprocess will be opened in cmd and closed automaticaly after installation.
-        # Prevents invoking pip by an old script wrapper (https://github.com/pypa/pip/issues/5599)
-        import subprocess
-        try:
-            subprocess.call('python -m pip install --upgrade pip')
-            subprocess.call('python -m pip install suds-py3 --user')
-            from suds.client import Client
-        except:
-            print('WARNING: Installation of SUDS library failed!')
-            print('Please use command "pip install suds-py3 --user" in your Command Prompt.')
-            input('Press Enter to exit...')
-            sys.exit()
-    else:
-        input('Press Enter to exit...')
-        sys.exit()
-
-try:
-    import requests
-except:
-    print('requests library is not installed in your Python env.')
-    instSUDS = input('Do you want to install it (y/n)? ')
-    instSUDS = instSUDS.lower()
-    if instSUDS == 'y':
-        # Subprocess will be opened in cmd and closed automaticaly after installation.
-        # Prevents invoking pip by an old script wrapper (https://github.com/pypa/pip/issues/5599)
-        import subprocess
-        try:
-            subprocess.call('python -m pip install requests --user')
-            import requests
-        except:
-            print('WARNING: Installation of requests library failed!')
-            print('Please use command "pip install requests --user" in your Command Prompt.')
-            input('Press Enter to exit...')
-            sys.exit()
-    else:
-        input('Press Enter to exit...')
-        sys.exit()
-
-try:
-    import suds_requests
-except:
-    print('suds_requests library is not installed in your Python env.')
-    instSUDS = input('Do you want to install it (y/n)? ')
-    instSUDS = instSUDS.lower()
-    if instSUDS == 'y':
-        # Subprocess will be opened in cmd and closed automaticaly after installation.
-        # Prevents invoking pip by an old script wrapper (https://github.com/pypa/pip/issues/5599)
-        import subprocess
-        try:
-            subprocess.call('python -m pip install suds_requests --user')
-            import suds_requests
-        except:
-            print('WARNING: Installation of suds_requests library failed!')
-            print('Please use command "pip install suds_requests --user" in your Command Prompt.')
-            input('Press Enter to exit...')
-            sys.exit()
-    else:
-        input('Press Enter to exit...')
-        sys.exit()
-
-try:
-    import xmltodict
-except:
-    print('xmltodict library is not installed in your Python env.')
-    instXML = input('Do you want to install it (y/n)? ')
-    instXML = instXML.lower()
-    if instXML == 'y':
-        # Subprocess will be opened in cmd and closed automaticaly after installation.
-        # Prevents invoking pip by an old script wrapper (https://github.com/pypa/pip/issues/5599)
-        import subprocess
-        try:
-            subprocess.call('python -m pip install xmltodict --user')
-            import xmltodict
-        except:
-            print('WARNING: Installation of xmltodict library failed!')
-            print('Please use command "pip install xmltodict --user" in your Command Prompt.')
-            input('Press Enter to exit...')
-            sys.exit()
-    else:
-        input('Press Enter to exit...')
-        sys.exit()
+from RFEM.suds_requests import RequestsTransport
 
 # Connect to server
 # Check server port range set in "Program Options & Settings"
@@ -122,42 +28,72 @@ except:
     sys.exit()
 
 # Persistent connection
-# Without next 4 lines the connection lasts only 1 request,
-# the message: 'Application is locked by external connection'
-# is blinking whole time and the execution is unnecessarily long.
-# This solution works with unit-tests.
+# Next 4 lines enables Client to work within 1 session which is much faster to execute.
+# Without it the session lasts only one request which results in poor performance.
+# Assigning session to application Client (here client) instead of model Client
+# results also in poor performace.
 session = requests.Session()
 adapter = requests.adapters.HTTPAdapter(pool_connections=1, pool_maxsize=1)
 session.mount('http://', adapter)
-trans = suds_requests.RequestsTransport(session)
+trans = RequestsTransport(session)
 
 class Model():
     clientModel = None
+    clientModelLst = []
+    activeSession = False
+
     def __init__(self,
                  new_model: bool=True,
                  model_name: str="TestModel",
                  delete: bool=False,
                  delete_all: bool=False):
+        """
+        Class object representing individual model in RFEM.
+        Class enables to edit multiple models in one session through holding
+        one transport session active by not setting 'trans' into Client.
+
+        Args:
+            new_model (bool, optional): Set to True if new model is requested.
+            model_name (str, optional): Defaults to "TestModel".
+            delete (bool, optional):  Delete results
+            delete_all (bool, optional): Delete all objects in Model.
+        """
 
         cModel = None
         modelLs = client.service.get_model_list()
 
         if new_model:
             if modelLs and model_name in modelLs.name:
-                new = client.service.open_model(model_name) + 'wsdl'
-                cModel = Client(new, transport=trans)
+                modelIndex = 0
+                for i,j in enumerate(modelLs.name):
+                    if modelLs.name[i] == model_name:
+                        modelIndex = i
+                new = client.service.get_model(modelIndex) + 'wsdl'
+                # Set transport parameter if it is the first model
+                if Model.activeSession:
+                    cModel = Client(new)
+                else:
+                    cModel = Client(new, transport=trans)
                 cModel.service.delete_all_results()
                 cModel.service.delete_all()
             else:
                 new = client.service.new_model(model_name) + 'wsdl'
-                cModel = Client(new, transport=trans)
+                if Model.activeSession:
+                    cModel = Client(new)
+                else:
+                    cModel = Client(new, transport=trans)
+                if not modelLs:
+                    Model.activeSession = True
         else:
             modelIndex = 0
-            for i,j in enumerate(modelLs):
-                if modelLs[i] == model_name:
+            for i,j in enumerate(modelLs.name):
+                if modelLs.name[i] == model_name:
                     modelIndex = i
             new = client.service.get_model(modelIndex) + 'wsdl'
-            cModel = Client(new, transport=trans)
+            if Model.activeSession:
+                cModel = Client(new)
+            else:
+                cModel = Client(new, transport=trans)
             if delete:
                 print('Deleting results...')
                 cModel.service.delete_all_results()
@@ -165,14 +101,28 @@ class Model():
                 print('Delete all...')
                 cModel.service.delete_all()
 
+        # when using multiple intances/model
+        self.clientModel = cModel
+        if not modelLs or not model_name in modelLs.name:
+            Model.clientModelLst.append(cModel)
+        # when using only one instace/model
         Model.clientModel = cModel
 
+
+    def __delete__(self, index):
+        if len(self.clientModelLst) == 1:
+            self.clientModelLst.clear()
+            self.clientModel = None
+        else:
+            self.clientModelLst.pop(index)
+            self.clientModel = self.clientModelLst[-1]
+
 def clearAtributes(obj):
     '''
     Clears object atributes.
     Sets all atributes to None.
 
-    Params:
+    Args:
         obj: object to clear
     '''
 
@@ -182,28 +132,40 @@ def clearAtributes(obj):
         obj[i[0]] = None
     return obj
 
+def closeModel(index_or_name, save_changes = False):
+    """
+    Close any model with index or name. Be sure to close the first created
+    model last (2,1, and then 0). It carries whole session.
+    """
+    if isinstance(index_or_name, int):
+        client.service.close_model(index_or_name, save_changes)
+        Model.__delete__(Model, index_or_name)
+    elif isinstance(index_or_name, str):
+        modelLs = client.service.get_model_list()
+        for i,j in enumerate(modelLs.name):
+            if modelLs.name[i] == index_or_name:
+                client.service.close_model(i, save_changes)
+    else:
+        assert True, 'Parameter index_or_name must be int or string.'
+
 def insertSpaces(lst: list):
     '''
     Add spaces between list of numbers.
     Returns list of values.
     '''
-    strLst = ''
-    for i in lst:
-        strLst += str(i) + ' '
-    # remove trailing space
-    return strLst[:-1]
+    return ' '.join(str(item) for item in lst)
 
-def Calculate_all(generateXmlSolverInput: bool = False):
+def Calculate_all(generateXmlSolverInput: bool = False, model = Model):
     '''
     Calculates model.
     CAUTION: Don't use it in unit tests!
     It works when executing tests individualy but when running all of them
     it causes RFEM to stuck and generates failures, which are hard to investigate.
 
-    Params:
+    Args:
     - generateXmlSolverInput: generate XML solver input
     '''
-    Model.clientModel.service.calculate_all(generateXmlSolverInput)
+    model.clientModel.service.calculate_all(generateXmlSolverInput)
 
 def ConvertToDlString(s):
     '''
@@ -215,7 +177,7 @@ def ConvertToDlString(s):
     '1-3'       -> '1 2 3'
     '1,3,5-9'   -> '1 3 5 6 7 8 9'
 
-    Params:
+    Args:
         RSTAB / RFEM common string
 
     Returns a WS conform string.
@@ -384,7 +346,7 @@ def SetAddonStatus(modelClient, addOn = AddOn.stress_analysis_active, status = T
 
         modelClient.service.set_addon_statuses(addonLst)
 
-def CalculateSelectedCases(loadCases: list = None, designSituations: list = None, loadCombinations: list = None):
+def CalculateSelectedCases(loadCases: list = None, designSituations: list = None, loadCombinations: list = None, model = Model):
     '''
     This method calculate just selected objects - load cases, desingSituations, loadCombinations
     Args:
@@ -392,10 +354,10 @@ def CalculateSelectedCases(loadCases: list = None, designSituations: list = None
         designSituations (list, optional): [description]. Defaults to None.
         loadCombinations (list, optional): [description]. Defaults to None.
     '''
-    specificObjectsToCalculate = Model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements')
+    specificObjectsToCalculate = model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements')
     if loadCases is not None:
         for loadCase in loadCases:
-            specificObjectsToCalculateLC = Model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements.element')
+            specificObjectsToCalculateLC = model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements.element')
             specificObjectsToCalculateLC.no = loadCase
             specificObjectsToCalculateLC.parent_no = 0
             specificObjectsToCalculateLC.type = ObjectTypes.E_OBJECT_TYPE_LOAD_CASE.name
@@ -403,7 +365,7 @@ def CalculateSelectedCases(loadCases: list = None, designSituations: list = None
 
     if designSituations is not None:
         for designSituation in designSituations:
-            specificObjectsToCalculateDS = Model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements.element')
+            specificObjectsToCalculateDS = model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements.element')
             specificObjectsToCalculateDS.no = designSituation
             specificObjectsToCalculateDS.parent_no = 0
             specificObjectsToCalculateDS.type = ObjectTypes.E_OBJECT_TYPE_DESIGN_SITUATION.name
@@ -411,58 +373,15 @@ def CalculateSelectedCases(loadCases: list = None, designSituations: list = None
 
     if loadCombinations is not None:
         for loadCombination in loadCombinations:
-            specificObjectsToCalculateLC = Model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements.element')
+            specificObjectsToCalculateLC = model.clientModel.factory.create('ns0:array_of_calculate_specific_objects_elements.element')
             specificObjectsToCalculateLC.no = loadCombination
             specificObjectsToCalculateLC.parent_no = 0
             specificObjectsToCalculateLC.type = ObjectTypes.E_OBJECT_TYPE_LOAD_CASE.name
             specificObjectsToCalculate.element.append(specificObjectsToCalculateLC)
 
-    Model.clientModel.service.calculate_specific_objects(specificObjectsToCalculate)
+    model.clientModel.service.calculate_specific_objects(specificObjectsToCalculate)
 
-def ExportResultTablesToCsv(TargetDirectoryPath: str):
-
-    Model.clientModel.service.export_result_tables_to_csv(TargetDirectoryPath)
-
-def ExportResultTablesToXML(TargetFilePath: str):
-
-    Model.clientModel.service.export_result_tables_to_xml(TargetFilePath)
-
-def ExportResultTablesWithDetailedMembersResultsToCsv(TargetDirectoryPath: str):
-
-    Model.clientModel.service.export_result_tables_with_detailed_members_results_to_csv(TargetDirectoryPath)
-
-def ExportResultTablesWithDetailedMembersResultsToXML(TargetFilePath: str):
-
-    Model.clientModel.service.export_result_tables_with_detailed_members_results_to_xml(TargetFilePath)
-
-def ParseCSVResultsFromSelectedFileToDict(filePath: str):
-
-    # Using encoding parameter ensures proper data translation, leaving out BOM etc.
-    # TODO: fix the value assigment; it only works with simple one-line header
-    #       consider all corner cases
-    with open(filePath, mode='r', encoding='utf-8-sig') as f:
-        reader = csv.DictReader(f,delimiter=';')
-        my_dictionary = []
-        for line in reader:
-            my_dictionary.append(line)
-    return my_dictionary
-
-def ParseXMLResultsFromSelectedFileToDict(filePath: str):
-
-    with open(filePath, "rb") as f:
-        my_dictionary = xmltodict.parse(f, xml_attribs=True)
-    return my_dictionary
-
-def GenerateMesh():
-
-    Model.clientModel.service.generate_mesh()
-
-def GetMeshStatistics():
-
-    mesh_stats = Model.clientModel.service.get_mesh_statistics()
-    return Model.clientModel.dict(mesh_stats)
-
-def FirstFreeIdNumber(memType = ObjectTypes.E_OBJECT_TYPE_MEMBER, parent_no: int = 0):
+def FirstFreeIdNumber(memType = ObjectTypes.E_OBJECT_TYPE_MEMBER, parent_no: int = 0, model = Model):
     '''
     This method returns the next available Id Number for the selected object type
     Args:
@@ -472,9 +391,9 @@ def FirstFreeIdNumber(memType = ObjectTypes.E_OBJECT_TYPE_MEMBER, parent_no: int
             (1) A geometric object has, in general, a parent_no = 0
             (2) The parent_no parameter becomes significant for example with loads
     '''
-    return Model.clientModel.service.get_first_free_number(memType.name, parent_no)
+    return model.clientModel.service.get_first_free_number(memType.name, parent_no)
 
-def SetModelType(model_type = ModelType.E_MODEL_TYPE_3D):
+def SetModelType(model_type = ModelType.E_MODEL_TYPE_3D, model = Model):
     '''
     This method sets the model type. The model type is E_MODEL_TYPE_3D by default.
 
@@ -490,12 +409,12 @@ def SetModelType(model_type = ModelType.E_MODEL_TYPE_3D):
             ModelType.E_MODEL_TYPE_3D
     '''
 
-    Model.clientModel.service.set_model_type(model_type.name)
+    model.clientModel.service.set_model_type(model_type.name)
 
-def GetModelType():
+def GetModelType(model = Model):
 
     '''
     The method returns a string of the current model type.
     '''
 
-    return Model.clientModel.service.get_model_type()
+    return model.clientModel.service.get_model_type()
